@@ -134,7 +134,7 @@ def plot(dict_list,
         >>> dl = hepi.load(urllib.request.urlopen(
         ... "https://raw.githubusercontent.com/fuenfundachtzig/xsec/master/json/pp13_hino_NLO%2BNLL.json"
         ... ))
-        >>> hepi.plot(dl,"N1","NLO_PLUS_NLL",xaxis=r"$m_{\tilde{\chi}_1^0}$")
+        >>> hepi.plot(dl,"N1","NLO_PLUS_NLL",xaxis="$m_{\\\\tilde{\\\\chi}_1^0}$")
     """
     if isinstance(y, Iterable) and not isinstance(y, str):
         for yi in y:
@@ -332,7 +332,7 @@ def mapplot(dict_list, x, y, z, xaxis=None, yaxis=None, zaxis=None, **kwargs):
         >>> dl = hepi.load(urllib.request.urlopen(
         ... "https://raw.githubusercontent.com/fuenfundachtzig/xsec/master/json/pp13_hinosplit_N2N1_NLO%2BNLL.json"
         ... ),dimensions=2)
-        >>> hepi.mapplot(dl,"N1","N2","NLO_PLUS_NLL",xaxis=r'$m_{\tilde{\chi}_1^0}$',yaxis=r'$m_{\tilde{\chi}_2^0}$' , zaxis="$\sigma_{\mathrm{NLO+NLL}}$")
+        >>> hepi.mapplot(dl,"N1","N2","NLO_PLUS_NLL",xaxis="$m_{\\\\tilde{\\\\chi}_1^0}$",yaxis="$m_{\\\\tilde{\\\\chi}_2^0}$" , zaxis="$\\\\sigma_{\\\\mathrm{NLO+NLL}}$")
     """
     if xaxis is None:
         xaxis = x
@@ -391,22 +391,33 @@ def map_vplot(vx,
         vx, vy = vy, vx
 
     grid = splot.unv(vz).reshape((int(np.rint(np.size(vx) / s)), s)) * zscale
+
+    fig, ax = plt.subplots(nrows=1, ncols=1, constrained_layout=True)
+    im = None
     if (logz):
-        plt.imshow(
-            grid,
+        im = NonUniformImage(
+            ax,
             origin="lower",
-            extent=(vx.min(), vx.max(), vy.min(), vy.max()),
             cmap='viridis',
-            #cmap=cm.gist_heat,
             interpolation='nearest',
-            norm=colors.LogNorm())
+            extent=(vx.min(), vx.max(), vy.min(), vy.max()),
+            norm=colors.LogNorm(),
+        )
     else:
-        plt.imshow(grid,
-                   origin="lower",
-                   extent=(vx.min(), vx.max(), vy.min(), vy.max()),
-                   cmap='viridis',
-                   interpolation='nearest')
-    cb = plt.colorbar()
+        im = NonUniformImage(
+            ax,
+            origin="lower",
+            cmap='viridis',
+            interpolation='nearest',
+            extent=(vx.min(), vx.max(), vy.min(), vy.max()),
+        )
+
+    im.set_data(np.unique(vx), np.unique(vy), grid)
+    ax.images.append(im)
+    ax.set_xlim(vx.min(), vx.max())
+    ax.set_ylim(vy.min(), vy.max())
+
+    cb = plt.colorbar(im)
     cb.set_label(zaxis)
     plt.xlabel(xaxis)
     plt.ylabel(yaxis)
